# Geohashr

*Just another Python geohashing library.*

## In a nutshell

```python
import geohashr

geohashr.encode(45.464664, 9.188540)
# 't18k68dr5kn8'

geohashr.decode('t18k68dr5kn8')
# (45.46466404572129, 9.188540065661073)
```

## License

Geohashr is released under the BSD License.
